@@ -7,20 +7,22 @@ You must implement the necessary permission checks in your own code before
 calling these methods!
 """
 import datetime
-from cms.constants import TEMPLATE_INHERITANCE_MAGIC
 
 from django.contrib.sites.models import Site
 from django.core.exceptions import FieldError
 from django.core.exceptions import PermissionDenied
 from django.core.exceptions import ValidationError
 from django.template.defaultfilters import slugify
+from django.template.loader import get_template
+from django.utils import six
 
 from cms.admin.forms import save_permissions
 from cms.app_base import CMSApp
 from cms.apphook_pool import apphook_pool
+from cms.constants import TEMPLATE_INHERITANCE_MAGIC
 from cms.models.pagemodel import Page
-from cms.models.permissionmodels import PageUser, PagePermission, \
-    GlobalPagePermission, ACCESS_PAGE_AND_DESCENDANTS
+from cms.models.permissionmodels import (PageUser, PagePermission,
+    GlobalPagePermission, ACCESS_PAGE_AND_DESCENDANTS)
 from cms.models.placeholdermodel import Placeholder
 from cms.models.pluginmodel import CMSPlugin
 from cms.models.titlemodels import Title
@@ -28,11 +30,9 @@ from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
 from cms.utils import copy_plugins
 from cms.utils.compat.dj import get_user_model
-from cms.utils.compat.type_checks import string_types
 from cms.utils.conf import get_cms_setting
 from cms.utils.i18n import get_language_list
 from cms.utils.permissions import _thread_locals
-from django.template.loader import get_template
 from menus.menu_pool import menu_pool
 
 
@@ -81,7 +81,7 @@ def _verify_apphook(apphook, namespace):
             print(apphook_pool.apps.values())
             raise
         return apphook.__name__
-    elif isinstance(apphook, string_types):
+    elif isinstance(apphook, six.string_types):
         try:
             assert apphook in apphook_pool.apps
         except AssertionError:
@@ -106,7 +106,7 @@ def _verify_plugin_type(plugin_type):
         plugin_model = plugin_type.model
         assert plugin_type in plugin_pool.plugins.values()
         plugin_type = plugin_type.__name__
-    elif isinstance(plugin_type, string_types):
+    elif isinstance(plugin_type, six.string_types):
         try:
             plugin_model = plugin_pool.get_plugin(plugin_type).model
         except KeyError:
