@@ -16,10 +16,17 @@ class PlaceholderField(models.ForeignKey):
         self.slotname = slotname
         self.default_width = default_width
         self.actions = actions()
+        if 'to' in kwargs:
+            del(kwargs['to'])
         kwargs.update({'null': True})  # always allow Null
         kwargs.update({'editable': False}) # never allow edits in admin
         super(PlaceholderField, self).__init__(Placeholder, **kwargs)
 
+    def deconstruct(self):
+        name, path, args, kwargs = super(PlaceholderField, self).deconstruct()
+        kwargs['slotname'] = self.slotname
+        return name, path, args, kwargs
+
     def _get_new_placeholder(self, instance):
         return Placeholder.objects.create(slot=self._get_placeholder_slot(instance), default_width=self.default_width)
 
