@@ -1,6 +1,6 @@
+from cms.utils.urlutils import admin_reverse
 from django.contrib.auth.models import Permission
 from django.contrib.sites.models import Site
-from django.core.urlresolvers import reverse
 
 from cms.api import create_page
 from cms.constants import PUBLISHER_STATE_DIRTY
@@ -185,7 +185,7 @@ class ExtensionAdminTestCase(AdminTestsBase):
         with self.login_user_context(self.admin):
             # add a new extension
             response = self.client.get(
-                reverse('admin:extensionapp_mypageextension_add') + '?extended_object=%s' % self.page_without_extension.pk
+                admin_reverse('extensionapp_mypageextension_add') + '?extended_object=%s' % self.page_without_extension.pk
             )
             self.assertEqual(response.status_code, 200)
             # make sure there is no extension yet
@@ -194,30 +194,30 @@ class ExtensionAdminTestCase(AdminTestsBase):
                 'extra': 'my extra'
             }
             response = self.client.post(
-                reverse('admin:extensionapp_mypageextension_add') + '?extended_object=%s' % self.page_without_extension.pk,
+                admin_reverse('extensionapp_mypageextension_add') + '?extended_object=%s' % self.page_without_extension.pk,
                 post_data, follow=True
             )
             created_page_extension = MyPageExtension.objects.get(extended_object=self.page_without_extension)
 
             # can delete extension
             response = self.client.post(
-                reverse('admin:extensionapp_mypageextension_delete', args=(created_page_extension.pk,)),
+                admin_reverse('extensionapp_mypageextension_delete', args=(created_page_extension.pk,)),
                 {'post': 'yes'}, follow=True
             )
             self.assertFalse(MyPageExtension.objects.filter(extended_object=self.page_without_extension).exists())
 
             # accessing the add view on a page that already has an extension should redirect
             response = self.client.get(
-                reverse('admin:extensionapp_mypageextension_add') + '?extended_object=%s' % self.page.pk
+                admin_reverse('extensionapp_mypageextension_add') + '?extended_object=%s' % self.page.pk
             )
-            self.assertRedirects(response, reverse('admin:extensionapp_mypageextension_change', args=(self.page_extension.pk,)))
+            self.assertRedirects(response, admin_reverse('extensionapp_mypageextension_change', args=(self.page_extension.pk,)))
 
             # saving an extension should work without the GET parameter
             post_data = {
                 'extra': 'my extra text'
             }
             self.client.post(
-                reverse('admin:extensionapp_mypageextension_change', args=(self.page_extension.pk,)),
+                admin_reverse('extensionapp_mypageextension_change', args=(self.page_extension.pk,)),
                 post_data, follow=True
             )
             self.assertTrue(MyPageExtension.objects.filter(extra='my extra text', pk=self.page_extension.pk).exists())
@@ -228,14 +228,14 @@ class ExtensionAdminTestCase(AdminTestsBase):
                 'extra': 'try to change extra text'
             }
             response = self.client.post(
-                reverse('admin:extensionapp_mypageextension_change', args=(self.page_extension.pk,)),
+                admin_reverse('extensionapp_mypageextension_change', args=(self.page_extension.pk,)),
                 post_data, follow=True
             )
             self.assertEqual(response.status_code, 403)
 
             # can't delete without page permission
             response = self.client.post(
-                reverse('admin:extensionapp_mypageextension_delete', args=(self.page_extension.pk,)),
+                admin_reverse('extensionapp_mypageextension_delete', args=(self.page_extension.pk,)),
                 {'post': 'yes'}, follow=True
             )
             self.assertEqual(response.status_code, 403)
@@ -245,7 +245,7 @@ class ExtensionAdminTestCase(AdminTestsBase):
         with self.login_user_context(self.admin):
             # add a new extension
             response = self.client.get(
-                reverse('admin:extensionapp_mytitleextension_add') + '?extended_object=%s' % self.page_title_without_extension.pk
+                admin_reverse('extensionapp_mytitleextension_add') + '?extended_object=%s' % self.page_title_without_extension.pk
             )
             self.assertEqual(response.status_code, 200)
             # make sure there is no extension yet
@@ -254,30 +254,30 @@ class ExtensionAdminTestCase(AdminTestsBase):
                 'extra_title': 'my extra title'
             }
             self.client.post(
-                reverse('admin:extensionapp_mytitleextension_add') + '?extended_object=%s' % self.page_title_without_extension.pk,
+                admin_reverse('extensionapp_mytitleextension_add') + '?extended_object=%s' % self.page_title_without_extension.pk,
                 post_data, follow=True
             )
             created_title_extension = MyTitleExtension.objects.get(extended_object=self.page_title_without_extension)
 
             # can delete extension
             self.client.post(
-                reverse('admin:extensionapp_mytitleextension_delete', args=(created_title_extension.pk,)),
+                admin_reverse('extensionapp_mytitleextension_delete', args=(created_title_extension.pk,)),
                 {'post': 'yes'}, follow=True
             )
             self.assertFalse(MyTitleExtension.objects.filter(extended_object=self.page_title_without_extension).exists())
 
             # accessing the add view on a page that already has an extension should redirect
             response = self.client.get(
-                reverse('admin:extensionapp_mytitleextension_add') + '?extended_object=%s' % self.page_title.pk
+                admin_reverse('extensionapp_mytitleextension_add') + '?extended_object=%s' % self.page_title.pk
             )
-            self.assertRedirects(response, reverse('admin:extensionapp_mytitleextension_change', args=(self.title_extension.pk,)))
+            self.assertRedirects(response, admin_reverse('extensionapp_mytitleextension_change', args=(self.title_extension.pk,)))
 
             # saving an extension should work without the GET parameter
             post_data = {
                 'extra_title': 'my extra text'
             }
             self.client.post(
-                reverse('admin:extensionapp_mytitleextension_change', args=(self.title_extension.pk,)),
+                admin_reverse('extensionapp_mytitleextension_change', args=(self.title_extension.pk,)),
                 post_data, follow=True
             )
             self.assertTrue(MyTitleExtension.objects.filter(extra_title='my extra text', pk=self.title_extension.pk).exists())
@@ -288,14 +288,14 @@ class ExtensionAdminTestCase(AdminTestsBase):
                 'extra_title': 'try to change extra text'
             }
             response = self.client.post(
-                reverse('admin:extensionapp_mytitleextension_change', args=(self.title_extension.pk,)),
+                admin_reverse('extensionapp_mytitleextension_change', args=(self.title_extension.pk,)),
                 post_data, follow=True
             )
             self.assertEqual(response.status_code, 403)
 
             # can't delete without page permission
             response = self.client.post(
-                reverse('admin:extensionapp_mytitleextension_delete', args=(self.title_extension.pk,)),
+                admin_reverse('extensionapp_mytitleextension_delete', args=(self.title_extension.pk,)),
                 {'post': 'yes'}, follow=True
             )
             self.assertEqual(response.status_code, 403)
