@@ -2,6 +2,7 @@
 from __future__ import with_statement
 import datetime
 import re
+from cms.utils.urlutils import admin_reverse
 
 from django.template.defaultfilters import truncatewords
 from django.contrib.auth.models import AnonymousUser, Permission
@@ -27,7 +28,6 @@ from cms.test_utils.testcases import (SettingsOverrideTestCase,
                                       URL_CMS_PAGE_ADD, URL_CMS_PAGE_CHANGE)
 from cms.test_utils.util.context_managers import SettingsOverride
 from cms.utils.compat import DJANGO_1_4
-from cms.utils.compat.dj import is_user_swapped
 from cms.utils.conf import get_cms_setting
 from cms.views import details
 
@@ -100,11 +100,7 @@ class ToolbarTests(ToolbarTestBase):
         # Logo + edit-mode + admin-menu + logout
         self.assertEqual(len(items), 2)
         admin_items = toolbar.get_or_create_menu(ADMIN_MENU_IDENTIFIER, 'Test').get_items()
-
-        if is_user_swapped:
-            self.assertEqual(len(admin_items), 6, admin_items)
-        else:
-            self.assertEqual(len(admin_items), 7, admin_items)
+        self.assertEqual(len(admin_items), 7, admin_items)
 
     def test_anon(self):
         page = create_page('test', 'nav_playground.html', 'en')
@@ -312,7 +308,7 @@ class ToolbarTests(ToolbarTestBase):
         superuser = self.get_superuser()
         create_page("home", "nav_playground.html", "en",
                            published=True)
-        resolve_url = reverse('admin:cms_page_resolve')
+        resolve_url = admin_reverse('cms_page_resolve')
         with self.login_user_context(superuser):
             response = self.client.post(resolve_url, {'pk': '', 'model': 'cms.page'})
             self.assertEqual(response.content.decode('utf-8'), '')
@@ -331,7 +327,7 @@ class ToolbarTests(ToolbarTestBase):
         with self.login_user_context(superuser):
             page_data = self.get_new_page_data()
             self.client.post(URL_CMS_PAGE_CHANGE % page2.pk, page_data)
-            url = reverse('admin:cms_page_resolve')
+            url = admin_reverse('cms_page_resolve')
             response = self.client.post(url, {'pk': page1.pk, 'model': 'cms.page'})
             self.assertEqual(response.content.decode('utf-8'), '/en/test-page-1/')
             response = self.client.post(url, {'pk': page1.pk, 'model': 'cms.page'})
@@ -562,11 +558,13 @@ class EditModelTemplateTagTest(ToolbarTestBase):
             '<h2></h2>',
         )
 
+        #
+        # NOTE: Using the render_placeholder "as" form should /not/ render
+        # frontend placeholder editing support.
+        #
         self.assertContains(
             response,
-            '<h3><div class="cms_placeholder cms_placeholder-{0}"></div>\n'
-            '<div class="cms_plugin cms_plugin-{1}">{2}</div></h3>'.format(ex1.placeholder.pk,
-                                                                           plugin.pk, render_placeholder_body)
+            '<h3>{0}</h3>'.format(render_placeholder_body)
             )
 
         self.assertContains(
