@@ -8,10 +8,15 @@ from django.contrib.sites.models import Site, SITE_CACHE
 from django.shortcuts import get_object_or_404
 from django.template import NodeList, VariableNode, TemplateSyntaxError
 from django.template.loader import get_template
-from django.template.loader_tags import ConstantIncludeNode, ExtendsNode, BlockNode
+from django.template.loader_tags import ExtendsNode, BlockNode
 from django.utils.translation import ugettext as _
 from sekizai.helpers import is_variable_extend_node
 
+try:
+    from django.template.loader_tags import ConstantIncludeNode as IncludeNode
+except ImportError:
+    from django.template.loader_tags import IncludeNode
+
 from cms.exceptions import DuplicatePlaceholderWarning, PluginLimitReached
 from cms.models import Page
 from cms.plugin_pool import plugin_pool
@@ -19,8 +24,8 @@ from cms.utils import get_language_from_request, permissions
 from cms.utils.compat.dj import force_unicode
 from cms.utils.i18n import get_fallback_languages
 from cms.utils.moderator import get_cmsplugin_queryset
-from cms.utils.placeholder import validate_placeholder_name, \
-    get_placeholder_conf
+from cms.utils.placeholder import (validate_placeholder_name,
+                                   get_placeholder_conf)
 
 
 def get_page_from_plugin_or_404(cms_plugin):
@@ -97,12 +102,17 @@ def _scan_placeholders(nodelist, current_block=None, ignore_blocks=None):
         # check if this is a placeholder first
         if isinstance(node, Placeholder):
             placeholders.append(node.get_name())
-        # if it's a Constant Include Node ({% include "template_name.html" %})
-        # scan the child template
-        elif isinstance(node, ConstantIncludeNode):
+        elif isinstance(node, IncludeNode):
             # if there's an error in the to-be-included template, node.template becomes None
             if node.template:
-                placeholders += _scan_placeholders(node.template.nodelist, current_block)
+                # This is required for Django 1.7 but works on older version too
+                # Check if it quacks like a template object, if not
+                # presume is a template path and get the object out of it
+                if not callable(getattr(node.template, 'render', None)):
+                    template = get_template(force_unicode(node.template).strip('"'))
+                else:
+                    template = node.template
+                placeholders += _scan_placeholders(template.nodelist, current_block)
         # handle {% extends ... %} tags
         elif isinstance(node, ExtendsNode):
             placeholders += _extend_nodelist(node)
@@ -348,7 +358,7 @@ def get_plugins_for_page(request, page, lang=None):
         return []
     lang = lang or get_language_from_request(request)
     if not hasattr(page, '_%s_plugins_cache' % lang):
-        slots = get_placeholders(page.template)
+        slots = get_placeholders(page.get_template())
         setattr(page, '_%s_plugins_cache' % lang, get_cmsplugin_queryset(request).filter(
             placeholder__page=page, placeholder__slot__in=slots, language=lang, parent__isnull=True
         ).order_by('placeholder', 'position').select_related())
