@@ -128,6 +128,15 @@ class DefaultLanguageChanger(object):
             if view.namespace:
                 "%s:%s" % (view.namespace, view_name)
             url = None
+            # every class-level argument is instantiated
+            # before reversing as reverse does not support
+            # classes as arguments
+            for idx, arg in enumerate(view.args):
+                if isinstance(arg, type):
+                    view.args[idx] = arg()
+            for key, arg in view.kwargs.items():
+                if isinstance(arg, type):
+                    view.kwargs[key] = arg()
             with force_language(lang):
                 try:
                     url = reverse(view_name, args=view.args, kwargs=view.kwargs, current_app=view.app_name)
